@@ -40,12 +40,6 @@ def get_par_list(self):
     
     return full_par_names_variable+full_par_names_fixed
 
-def delta(cumul):
-    diff = []
-    for i in range(1,len(cumul)):
-        diff.append(cumul[i] - cumul[i-1])
-    return diff
-
 def get_tab(self):
     
     output = widgets.Output()
@@ -60,7 +54,7 @@ def get_tab(self):
         
         for pop_name in self.model.populations:
             pop = self.model.populations[pop_name]
-            if not pop.hidden:
+            if (not pop.hidden) and pop.show_sim:
                 t = range(len(pop.history))
                 axis.plot(t, pop.history, lw=2, label=pop_name, color=pop.color, zorder=2)
 
@@ -75,7 +69,9 @@ def get_tab(self):
                     values = []
                     for model in models:
                         sim_pop = model.populations[pop_name]
-                        values.append(sim_pop.history[x]-sim_pop.history[x_ref]-dy_ref)
+                        # scale the models to the same value at x_ref
+                        scale = pop.history[x_ref]/sim_pop.history[x_ref]
+                        values.append((sim_pop.history[x]-sim_pop.history[x_ref])*scale - dy_ref)
                     lower.append(np.percentile(values,2.5))
                     upper.append(np.percentile(values,97.5))
                     
@@ -355,9 +351,16 @@ def get_tab(self):
     def do_auto_cov(b):
         output.clear_output(True)
         n_rep = n_rep_widget.value
-        self.optimizer.calc_auto_covariance(n_rep)
-        with output:
-            print('Autocovariance calculated')
+        n_points = self.optimizer.data_range[1] - self.optimizer.data_range[0]
+        if n_rep < 2*n_points:
+            with output:
+                print('Not enough repititions to calculate the')
+                print('autocovariance. Should be more than double the')
+                print('number of data points.')
+        else:
+            self.optimizer.calc_auto_covariance(n_rep)
+            with output:
+                print('Autocovariance calculated')
                 
     auto_cov_button.on_click(do_auto_cov)
 
@@ -365,6 +368,7 @@ def get_tab(self):
         output.clear_output(True)
         n_rep = n_rep_widget.value
         self.optimizer.calc_chi2f = chi2f_checkbox.value
+        self.optimizer.calc_chi2s = True
         self.optimizer.calc_sim_gof(n_rep)
         with output:
             print('Simulated goodness of fit distribution calculated')
